@@ -141,7 +141,8 @@ def attachSettings(settingsDict, enablePaypal=False):
     # Oscar default settings 
     addOscarDefaultsPackages = {}
     oscarDefaultsPackages = __import__(
-        'oscar', globals(), locals(), [], -1).__dict__['defaults']
+            'oscar.defaults', globals(), locals(), [], -1
+        ).__dict__['defaults']
     for attr in dir(oscarDefaultsPackages):
         addOscarDefaultsPackages[attr] = getattr(
             oscarDefaultsPackages, attr)
